# Risk Management Agent

To fulfill your requests, our built-in tools can generate and execute Python code or system commands. To protect you from running generated code or command that could pose a risk to your system, such as file deletion, ToolMate AI has a built-in risk management agent. This agent assesses the risk level of generated code and prompts you for confirmation before execution. 

To specify the risk threshold or determine the level at which you will be asked for confirmation, enter `.managerisk` in ToolMate AI prompt or select `manage code execution risk` from ToolMate AI [action menu](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Action%20Menu.md). (Note: Confirming code execution is done at your own risk.)

# Screenshots

## Running system command

![risk_ax_agent](https://github.com/user-attachments/assets/d7da6ac3-a697-4b6c-8555-0636fde041a6)

## Running python code

![toolmate_ai_screenshot](https://github.com/eliranwong/toolmate/assets/25262722/1e9dd18e-aa4b-4e2c-8d76-386af7ba00ea)